model Package
=============

:mod:`model` Package
--------------------

.. automodule:: camelot.model
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`authentication` Module
----------------------------

.. automodule:: camelot.model.authentication
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`batch_job` Module
-----------------------

.. automodule:: camelot.model.batch_job
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`fixture` Module
---------------------

.. automodule:: camelot.model.fixture
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`i18n` Module
------------------

.. automodule:: camelot.model.i18n
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`memento` Module
---------------------

.. automodule:: camelot.model.memento
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`synchronization` Module
-----------------------------

.. automodule:: camelot.model.synchronization
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`task` Module
------------------

.. automodule:: camelot.model.task
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`type_and_status` Module
-----------------------------

.. automodule:: camelot.model.type_and_status
    :members:
    :undoc-members:
    :show-inheritance:

